@@ -26,17 +26,15 @@ try:
 except ImportError:
     from xcffib.ffi_build import ffi
 
-SONAMES = {
-    "Linux": "libxcb.so.1",
-    "Darwin": "libxcb.dylib",
-}
+soname = "libxcb.so.1"
+if platform.system() == "Darwin":
+    soname = "libxcb.dylib"
+elif platform.system() == "Windows":
+    soname = "libxcb.dll"
+lib = ffi.dlopen(soname)
 
-try:
-    lib = ffi.dlopen(SONAMES[platform.system()])
-except KeyError:
-    raise NotImplementedError("unsupported platform %s" % platform.system())
-
-__xcb_proto_version__ = "1.11"
+__xcb_proto_version__ = "1.12"
+__version__ = 'placeholder'
 
 X_PROTOCOL = lib.X_PROTOCOL
 X_PROTOCOL_REVISION = lib.X_PROTOCOL_REVISION
@@ -329,6 +327,9 @@ class Cookie(object):
             "Request is not void and checked")
         self.conn.request_check(self.sequence)
 
+    def discard_reply(self):
+        return self.conn.discard_reply(self.sequence)
+
 
 class VoidCookie(Cookie):
 
@@ -448,7 +449,7 @@ class List(Protobj):
 
     def to_atoms(self):
         """ A helper for converting a List of chars to an array of atoms """
-        return struct.unpack("=" + "I" * (len(self) // 4), b''.join(self))
+        return struct.unpack("<" + "I" * (len(self) // 4), b''.join(self))
 
     def buf(self):
         return b''.join(self.list)
@@ -651,7 +652,10 @@ class Connection(object):
 
         reply = ffi.cast("xcb_generic_reply_t *", data)
 
-        # why is this 32 and not sizeof(xcb_generic_reply_t) == 8?
+        # this is 32 and not `sizeof(xcb_generic_reply_t) == 8` because,
+        # according to the X11 protocol specs: "Every reply consists of 32 bytes
+        # followed by zero or more additional bytes of data, as specified in the
+        # length field."
         return CffiUnpacker(data, known_max=32 + reply.length * 4)
 
     @ensure_connected
@@ -680,6 +684,10 @@ class Connection(object):
     def send_request(self, flags, xcb_parts, xcb_req):
         return lib.xcb_send_request(self._conn, flags, xcb_parts, xcb_req)
 
+    @ensure_connected
+    def discard_reply(self, sequence):
+        return lib.xcb_discard_reply(self._conn, sequence)
+
 
 # More backwards compatibility
 connect = Connection
